/***********************************************************
*
*	对51单片机常用的函数的定义，方便代码重构
*
*	Author:		小苹果青的
*	CreateDate:	2015年12月11日
*
*	UpdateDate:	2015年12月12日
*************************************************************/



typedef unsigned char u8;
typedef unsigned int u16;

#define DATA P0   //对P0口的重命名
/*******端口定义*******/
sbit seg_sel = P3^0;
sbit bit_sel = P3^1;

//段码 共阴极
u8 code seg_table[] = {0x3f,0x06,0x5b,0x4f,0x66,0x6d,0x7d,0x07,0x7f,0x6f,0x77,0x7c,0x39,0x5e,0x79,0x71,0x40,0x80};
//位码 共阴极
u8 code bit_table[] = {0x7f,0xbf,0xdf,0xef,0xf7,0xfb,0xfd,0xfe}; //位是从右往左
//存储秒表中的各位段码
u8 viewData[8];

/*
初始化数码管以及锁存器
*/
void init_digital_latch()
{
	P0 = 0xff;
    P1 = 0xff; //初始化端口
    
    seg_sel = 1;
    bit_sel = 1; //禁止锁存
}


/*
延迟函数
[number]：延迟的时间，单位毫秒(ms)
*/
void delay(u16 number)
{
    u16 x,y;
    
    for(x = number;x > 0;x--)
        for(y = 120;y>0;y--); //此循环的值根据芯片的震荡频率设定  大约1毫秒
}


/*
LED液晶管显示
[which_bit]：控制哪个位显示
[which_number]：控制显示的字符，集合的索引，最大17(0123456789ABCDEF-.)
*/
void display_led(u8 which_bit,u8 which_number)
{
	
    
    DATA = bit_table[which_bit]; //取位码
    bit_sel = 1;//同步锁存器 Q[8..1] = D[8..1]
    bit_sel = 0;   
    
    
    DATA = seg_table[which_number]; //取段码
	seg_sel = 1;
    seg_sel = 0;  
	
    //DATA = 0xff;
	
   
    //每次显示完延迟1毫秒清除缓存 
	delay(1);
    /**************************************
    ***实际延迟时间需要根据不同的功能而定*****
    ***************************************/
    
}



/*
秒表的显示,LED数码管显示模式的一种
[min]：要显示的分钟
[sec]：要显示的秒
[msec]：要显示的毫秒
*/
void digital_view_stopwatch(u8 min,u8 sec,u8 msec)
{
	u8 index; //记录秒表显示位的索引
    viewData[0] = msec % 10;  //段码实际值
	viewData[1] = msec / 10;
	viewData[2] = 16; // “-”段码 seg_table[16]  -- 0x40
	viewData[3] = sec % 10;
	viewData[4] = sec / 10;
	viewData[5] = 16;
	viewData[6] = min % 10;
	viewData[7] = min / 10;
	
	//扫描数码管
	for(index = 0; index < 8; index++)
	{
		display_led(index,viewData[index]);
	}
}



